summaryrefslogtreecommitdiff
path: root/usr.bin/error/error.h
diff options
context:
space:
mode:
authorwsanchez <wsanchez@NetBSD.org>1998-10-08 01:29:27 +0000
committerwsanchez <wsanchez@NetBSD.org>1998-10-08 01:29:27 +0000
commitd2b96d3f77535a6b4b68bc7204cb724a50a1b452 (patch)
tree80ab8b69858c75423182054541abf53c7815bb81 /usr.bin/error/error.h
parent974aa74abd2e7fca95e0253a90f67af72bc8d622 (diff)
Get rid of multiply defined common symbols
langauge should be language in error.h
Diffstat (limited to 'usr.bin/error/error.h')
-rw-r--r--usr.bin/error/error.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/usr.bin/error/error.h b/usr.bin/error/error.h
index cf0ce6902ef..6fe1431c42c 100644
--- a/usr.bin/error/error.h
+++ b/usr.bin/error/error.h
@@ -1,4 +1,4 @@
-/* $NetBSD: error.h,v 1.4 1997/10/18 14:44:25 lukem Exp $ */
+/* $NetBSD: error.h,v 1.5 1998/10/08 01:29:27 wsanchez Exp $ */
/*
* Copyright (c) 1980, 1993
@@ -110,8 +110,8 @@ extern int class_count[];
#define TOTHEFILE 1 /* touch the file */
#define TOSTDOUT 2 /* just print them out (ho-hum) */
-FILE *errorfile; /* where error file comes from */
-FILE *queryfile; /* where the query responses from the user come from*/
+extern FILE *errorfile; /* where error file comes from */
+extern FILE *queryfile; /* where the query responses from the user come from*/
extern char *currentfilename;
extern char *processname;
@@ -170,8 +170,8 @@ extern struct lang_desc lang_table[];
*/
#define ERRORNAME "/.errorrc"
-int nignored;
-char **names_ignored;
+extern int nignored;
+extern char **names_ignored;
/*
* Structure definition for a full error
*/
@@ -200,13 +200,13 @@ extern Eptr *errors;
*/
extern int nfiles;
extern Eptr **files; /* array of pointers into errors*/
-boolean *touchedfiles; /* which files we touched */
+extern boolean *touchedfiles; /* which files we touched */
/*
* The langauge the compilation is in, as intuited from
* the flavor of error messages analyzed.
*/
-extern int langauge;
+extern int language;
extern char *currentfilename;
/*
@@ -200,13 +200,13 @@ extern Eptr *errors;
/*
- * The langauge the compilation is in, as intuited from
+ * The language the compilation is in, as intuited from
* the flavor of error messages analyzed.
*/